pm4py.statistics.util package
=============================

Submodules
----------

pm4py.statistics.util.times\_bipartite\_matching module
-------------------------------------------------------

.. automodule:: pm4py.statistics.util.times_bipartite_matching
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.util
   :members:
   :undoc-members:
   :show-inheritance:
